Dr A. Yang
12/10/2025, 2:03 PMAustyn Trull
12/10/2025, 2:33 PMprocess
{
withName: '.*:BLAZE'
{
cpus = 30
}
}
And then add a flag like -c custom.conf to the nextflow run command
Ill also note do have a PR that includes an alternative barcode calling tool (flexiplex) that would maybe help but its still in reviewDr A. Yang
12/10/2025, 2:37 PMDr A. Yang
12/10/2025, 2:42 PMLara Ianov
12/10/2025, 3:21 PMprocess
{
withName: '.*:.*BLAZE.*'
{
cpus = 45
memory = '55.GB'
}
}Dr A. Yang
12/10/2025, 3:25 PMLara Ianov
12/10/2025, 4:06 PM--kit-version for instance is a parameter in BLAZE. We would need to add any additional custom parameters (along with existing ones) to a custom.config.
The only thing is that we recommend to test this first on the test data to ensure that the expected outputs are still produced.
Let me and @Austyn Trull check this parameter you mentioned in the test data and we can come back to this discussion - hopefully this will make your implementation easier.Dr A. Yang
12/10/2025, 4:12 PMprocess {
withName: '.*:BLAZE' {
ext.args = {
[
"--kit-version ${params.barcode_format.minus('10X_')}",
"--no-demultiplexing"
].join(' ').trim()
}
}
}Lara Ianov
12/10/2025, 4:13 PMAustyn Trull
12/10/2025, 4:15 PMprocess {
withName: '.*:BLAZE' {
cpus = 45
memory = '55.GB'
ext.args = {
[
"--kit-version ${params.barcode_format.minus('10X_')}",
"--no-demultiplexing"
].join(' ').trim()
}
}
}
But I agree with Lara, we'll test it with a smaller dataset and report backLara Ianov
12/10/2025, 6:34 PMAustyn Trull
12/10/2025, 6:43 PMDr A. Yang
12/10/2025, 9:35 PMDr A. Yang
12/11/2025, 3:54 PM--no-demultiplexing option the BLAZE job ran much faster and did not timeout using the same 30 CPU configuration as before. The run took 4hrs 18min, whereas the previously timed out job was killed after 12 hours (and according to BLAZE log, it has been demultiplexing for 6hrs 44min by the time it was killed). I do think that this option should be enabled by default as it saves quite a substantial amount of time given that it does not need to read in the FASTQ file again nor write out another FASTQ file (this is becoming another real issue in my analysis, which I will post in a separate thread just to keep things organised).Austyn Trull
12/11/2025, 3:59 PMLara Ianov
12/11/2025, 4:47 PMLara Ianov
06/26/2026, 9:36 PM